@@ -15,7 +15,15 @@ class BBBDLC:
         }
 
         try:
-            ncPath = subprocess.check_output("/opt/plesk/php/7.3/bin/php " + args.ncDir + " config:system:get datadirectory", shell=True).decode('utf-8').strip()
+            subprocessCommand = "/opt/plesk/php/7.3/bin/php " + args.ncDir + " config:system:get datadirectory"
+            print(subprocessCommand)
+
+            ncPath = subprocess.check_output(subprocessCommand, shell=True)
+            print(ncPath)
+            ncPath = ncPath.decode('utf-8')
+            print(ncPath)
+            ncPath = ncPath.strip()
+            print(ncPath)
 
             if ncPath == "": raise NameError('Could not find nextcloud config!')
             
